;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "epkg-marginalia" "20251012.1349"
  "Show Epkg information in completion annotations."
  '((emacs      "28.1")
    (compat     "30.1")
    (epkg       "4.1")
    (marginalia "2.3"))
  :url "https://github.com/emacscollective/epkg-marginalia"
  :commit "7418f8e9690efa9d6821a63bf815d3b868a425ba"
  :revdesc "7418f8e9690e"
  :keywords '("tools")
  :authors '(("Jonas Bernoulli" . "emacs.epkg-marginalia@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.epkg-marginalia@jonas.bernoulli.dev")))
